@@ -1,25 +1,42 @@
-import warnings
 from ..Ion import Ion
-import sys
 from math import log, log10, sqrt
 
 
 class Solution(object):
 
-    """Represent a solution containing a set of ions.
+    """Describe an aqueous solution.
 
-    Initialize with solution(ions, concentrations), where ions is a list
-    containing AspPy ion objects, and concentrations is a list containing
-    positive scalars. Can also take T as an optional temperature argument, in
-    Celcius.
+    Args:
+        ions (list): A list of valence states for the ion, as integers.
 
-    When a new solution is initialized, it will immediately calculate the
-    equilibrium state, including the pH and the ionic strength (I) of the
-    solution. These values willl be stored as permenant attributes of the
-    object. Other solution properties can be calculated by invoking the
-    appropriate method.
+        concentrations (list): The pKa of each valence at the refernce
+        temperature, as floats.
 
-    See also Ion.
+        T (float): The temperature to use to calculate the properties of the
+        ions, in degrees C.
+
+    Attributes:
+        ions (list): A list of valence states for the ion, as integers.
+
+        concentrations (list): The pKa of each valence at the reference
+        temperature, as floats.
+
+        T (float): The temperature to use to calculate the properties of the
+        ions, in degrees C.
+
+    Raises:
+        None
+
+    Example:
+        To to initialize an Soltuion, call as:
+
+        >>> ionize.Solution([ion1, ion2], [c1, c2], T=30)
+
+        When a new Solution is initialized, it will immediately calculate the
+        equilibrium state, including the pH and the ionic strength (I) of the
+        solution. These values willl be stored as permenant attributes of the
+        object. Other solution properties can be calculated by invoking the
+        appropriate method.
     """
 
     _F = 96485.3415        # Faraday's const.           [C/mol]
@@ -65,20 +82,20 @@ class Solution(object):
             """Must be initialized with the same number of ions and concentrations.
         """
 
-        assert all([c >= 0 for c in concentrations]),\
+        assert all([c >= 0 for c in self.concentrations]),\
             """Concentrations must be positive."""
 
         if self.ions:
-            (self.pH, self.I) = self.find_equilibrium()
+            (self.pH, self.I) = self._find_equilibrium()
         else:
             self.pH = -log10(sqrt(self._Kw))
-            self.I = self.calc_I(self.pH)
+            self.I = self._calc_I(self.pH)
 
         for ion in self.ions:
             ion._I = self.I
             ion._pH = self.pH
 
-        actual_mobilities = self.onsager_fuoss()
+        actual_mobilities = self._onsager_fuoss()
 
         for i in range(len(self.ions)):
             self.ions[i].actual_mobility = actual_mobilities[i]
@@ -86,17 +103,17 @@ class Solution(object):
         self._H.actual_mobility = [actual_mobilities[-1][0]]
         self._OH.actual_mobility = [actual_mobilities[-1][1]]
 
-    def adjust_Kw(obj):
-        pKw_ref = -log10(obj._Kw_ref)
-        T_ref = obj._T_ref + 273.15
-        T = obj.T + 273.15
+    def adjust_Kw(self):
+        pKw_ref = -log10(self._Kw_ref)
+        T_ref = self._T_ref + 273.15
+        T = self.T + 273.15
         pKw = pKw_ref -\
-            (obj._dHw/2.303/obj._R)*(1.0/T_ref - 1.0/T) -\
-            (obj._dCpw/2.303/obj._R)*(T_ref/T-1.0+log(T/T_ref))
+            (self._dHw/2.303/self._R)*(1.0/T_ref - 1.0/T) -\
+            (self._dCpw/2.303/self._R)*(T_ref/T-1.0+log(T/T_ref))
         Kw = 10.0**(-pKw)
         return Kw
 
-    def buffering_capacity(obj):
+    def buffering_capacity(self):
         """Return the buffering capacity of the solution.
 
         This function generates an approximate solution to the buffering
@@ -104,66 +121,66 @@ class Solution(object):
         the addition of an acid insult at small concentration.
         """
         # Remove any ions at concentration 0.
-        c = 0.001*min([cp for cp in obj.concentrations if cp > 0])
+        c = 0.001*min([cp for cp in self.concentrations if cp > 0])
         Cb = 0
 
         # Add an acid insult at 0.1% the lowest concentration in the solution.
         # If the buffering capacity is measured as above the insult c,
         # make the insult c lower.
         while Cb < c:
-            new_sol = obj + (Ion('Acid Insult', -1, -2, -1), c)
+            new_sol = self + (Ion('Acid Insult', -1, -2, -1), c)
             # Find the slope of the pH.
-            Cb = abs(c/(obj.pH-new_sol.pH))
+            Cb = abs(c/(self.pH-new_sol.pH))
             c = 0.01 * Cb
         return Cb
 
-    def cH(obj, pH=None, I=None):
+    def cH(self, pH=None, I=None):
         """Return the concentration of protons in solution."""
         if not pH:
-            pH = obj.pH
+            pH = self.pH
 
         if not I:
-            I = obj.I
+            I = self.I
 
-        cH = 10**(-pH)/obj._H.activity_coefficient(I, [1])[0]
+        cH = 10**(-pH)/self._H.activity_coefficient(I, [1])[0]
         return cH
 
-    def cOH(obj, pH=None, I=None):
+    def cOH(self, pH=None, I=None):
         """Return the concentration of hydroxyls in solution."""
         if not pH:
-            pH = obj.pH
+            pH = self.pH
 
         if not I:
-            I = obj.I
+            I = self.I
 
-        cOH = obj.Kw_eff(I)/obj.cH(pH)
+        cOH = self.Kw_eff(I)/self.cH(pH)
         return cOH
 
-    def H_conductivity(obj):
+    def H_conductivity(self):
         """Return the conductivity of protons in solution.
 
         Corrects for the mobility of the ion using the
-        ion object's actual mobility.
+        ion objects's actual mobility.
         """
-        H_conductivity = obj.cH()*obj._H.molar_conductivity(obj.pH, obj.I)
+        H_conductivity = self.cH()*self._H.molar_conductivity(self.pH, self.I)
         return H_conductivity
 
-    def OH_conductivity(obj):
+    def OH_conductivity(self):
         """Return the conductivity of hydroxyls in solution.
 
         Corrects for the mobility of the ion using the
         ion object's actual mobility.
         """
-        OH_conductivity = obj.cOH()*obj._OH.molar_conductivity(obj.pH, obj.I)
+        OH_conductivity = self.cOH()*self._OH.molar_conductivity(self.pH, self.I)
         return OH_conductivity
 
-    def __add__(obj, other):
-        new_i = obj.ions[:]
-        new_c = obj.concentrations[:]
+    def __add__(self, other):
+        new_i = self.ions[:]
+        new_c = self.concentrations[:]
         if isinstance(other, Solution):
             for ion, c in zip(other.ions, other.concentrations):
-                if ion in obj.ions:
-                    new_c[obj.ions.index(ion)] += c
+                if ion in self.ions:
+                    new_c[self.ions.index(ion)] += c
                 else:
                     new_i.append(ion)
                     new_c.append(c)
@@ -171,8 +188,8 @@ class Solution(object):
         elif isinstance(other, (list, tuple)) and len(other) == 2 and\
                 isinstance(other[0], Ion) and isinstance(other[1], (int, float)):
             ion, c = other
-            if ion in obj.ions:
-                new_c[obj.ions.index(ion)] += c
+            if ion in self.ions:
+                new_c[self.ions.index(ion)] += c
             else:
                 new_i.append(ion)
                 new_c.append(c)
@@ -182,36 +199,35 @@ class Solution(object):
 
     __radd__ = __add__
 
-    def __mul__(obj, other):
+    def __mul__(self, other):
         if other >= 0:
-            return Solution(obj.ions,
-                            [c * other for c in obj.concentrations])
+            return Solution(self.ions,
+                            [c * other for c in self.concentrations])
         else:
             raise NotImplementedError
 
     __rmul__ = __mul__
 
-    def __str__(obj):
+    def __str__(self):
         """Return a string representing the Solution."""
-        return "Solution object -- pH = " + str(obj.pH) + \
-            ", I = " + str(obj.I) + ' M'
+        return "Solution(pH={:.3g}, I={:.3g} M)".format(self.pH, self.I)
 
-    def __repr__(obj):
+    def __repr__(self):
         """Return a representation of the Solution."""
-        return obj.__str__()
+        return self.__str__()
 
-    def __len__(obj):
-        return len(obj.ions)
+    def __len__(self):
+        return len(self.ions)
 
-    from calc_I import calc_I
-    from calc_pH import calc_pH
-    from conductivity import conductivity
-    from equil_offset import equil_offset
-    from find_equilibrium import find_equilibrium
-    from Kw_eff import Kw_eff
-    from onsager_fuoss import onsager_fuoss
-    from transference import transference
-    from zone_transfer import zone_transfer
-    from ..dielectric import dielectric
-    from ..viscosity import viscosity
-    from conservation import kohlrausch, alberty, jovin
+    from .calc_I import calc_I as _calc_I
+    from .calc_pH import calc_pH as _calc_pH
+    from .conductivity import conductivity
+    from .equil_offset import equil_offset as _equil_offset
+    from .find_equilibrium import find_equilibrium as _find_equilibrium
+    from .Kw_eff import Kw_eff
+    from .onsager_fuoss import onsager_fuoss as _onsager_fuoss
+    from .transference import transference
+    from .zone_transfer import zone_transfer
+    from ..dielectric import dielectric as _dielectric
+    from ..viscosity import viscosity as _viscosity
+    from .conservation import kohlrausch, alberty, jovin
