@@ -1,5 +1,4 @@
 import re
-import os
 from get_db import get_db
 
 
@@ -10,14 +9,17 @@ def search_ion(searchstring):
     """
     ion_list = get_db()
 
-    if searchstring.lower() in ion_list.keys():
-        print searchstring
-    else:
-        for name in sorted(ion_list.keys()):
-            if re.search(searchstring, name):
-                print name
-    ion_list.close()
-    return None
+    ions = []
+
+    for name in sorted(ion_list.keys()):
+        if re.search(searchstring, name):
+            ions.append(name)
+
+    return [str(i) for i in ions]
 
 if __name__ == '__main__':
-    search_ion('fluor')
+    for ion in search_ion('fluor'):
+        print ion
+
+    print '\n'
+    print search_ion('fluor')
